@@ -62,6 +62,7 @@ def update_or_create_django_instance_from_redis_instance(
             django_id,
             django_many_to_many_params
         )
+        print(f'Added {django_instance.__class__.__name__}:{django_id} to django from cache')
     return django_instance
 
 
@@ -143,6 +144,7 @@ def update_or_create_redis_instance_from_django_instance(
             django_id=django_instance.id,
             **redis_dict
         ).save()
+        print(f'Added {django_instance.__class__.__name__}:{django_instance.id} to cache from django')
     else:
         redis_instance = redis_instance[0]
         redis_root.update(redis_model, redis_instance,
